@@ -185,6 +185,8 @@ class DeclarativeBase(db.Model, CoreMixin):
                 for index, entry in enumerate(relationship_instance):
                     fields = set(entry.keys()).difference(exclude)
                     if sublookup:
+                        if not resp.get(parent, None):
+                            resp[parent] = dict()
                         resp[parent].setdefault(attr, []).append(entry.extract(fields))
                     else:
                         resp[item].append(entry.extract(set(entry.keys()).difference(exclude)))
